@@ -17,7 +17,9 @@ import json
 from string import Template
 from functools import wraps
 from decorator import decorator
-from autodoc._compat import to_unicode
+from autodoc._compat import to_unicode, parse_qsl
+
+__version__ = '0.3'
 
 
 class Response(object):
@@ -59,6 +61,53 @@ class WebTestResponse(Response):
         return ret
 
 
+class RequestsResponse(Response):
+    def parse(self, response):
+        """Parse requests response.
+
+        :param response: requests response object
+        """
+        content_type = response.headers['Content-Type']
+        status = response.status_code
+        params = ''
+
+        response_body = ''
+        if to_unicode(response.content) != '':
+            response_body = json.loads(to_unicode(response.content))
+            #: Format indent.
+            #: {'foo': 'bar'}
+            #:   will format to
+            #: {
+            #:   'foo': 'bar'
+            #: }
+            response_body = json.dumps(response_body, indent=2)
+
+        request = response.request
+        if request.body != '':
+            data = parse_qsl(request.body)
+            request_params = {}
+            for v in data:
+                #: v[0] = parameter key
+                #: v[1] = parameter value
+                #: ex:
+                #:   user_id=foo&email=foo%40example.com
+                #: v[0] = user_id
+                #: v[1] = foo
+                request_params[v[0]] = v[1]
+            params = json.dumps(request_params, indent=2)
+
+        ret = {
+            'status_code': status,
+            'response_content_type': content_type,
+            'response_body': response_body,
+            'target_url': request.url,
+            'request': '{0} {1}'.format(request.method, request.path_url),
+            'params': params
+        }
+
+        return ret
+
+
 class Autodoc(object):
     def __init__(self):
         self.clear()
@@ -79,6 +128,8 @@ class Autodoc(object):
         """
         if response.__module__ == 'webtest.response':
             klass = WebTestResponse()
+        elif response.__module__ == 'requests.models':
+            klass = RequestsResponse()
         else:
             return
 
